@@ -26,9 +26,13 @@ class BertSTEM:
 
         return(sentence_encoder(df, self._model, self._tokenizer, column, encoding))
 
-    def _train_bert_for_pretraining(self, text, checkpoint = self.model_name):
+    def _train_bert_for_pretraining(self, text, checkpoint):
         
         model = transformers.BertForPreTraining.from_pretrained(checkpoint)
+        
+        tokenizer = transformers.BertTokenizerFast.from_pretrained(checkpoint,
+                                                                   do_lower_case = True,
+                                                                   add_special_tokens = False)
 
         train_Bert4PT(model, tokenizer, text)
 
